import io
import json
from pathlib import Path
import os.path
from typing import List, Optional, Callable, Any, Tuple, Set
import pytest
from pytest_steps import test_steps
from copy import deepcopy

from api_process_findings import ProcessingSettings
from helpers.db_models import DbTemplate, DbPwndocMapping
from tests.conftest import TMP_PATH, PWNDOC_DANGER_OVERRIDE
from tests.test_findings_parsing import test_connectivity, PwnDocCommunication
from tests.test_templating import delete_templates
from tests.helper_generate_finding_file import generate_text_for_issues
from tests.test_finding_grouping import FindingHelper
import config
from loguru import logger


@pytest.mark.skipif(not PWNDOC_DANGER_OVERRIDE, reason="PWNDOC_DANGER_OVERRIDE must be allowed to enable testing of interaction with PwnDoc")
@pytest.mark.dependency(depends=["test_connectivity"])
class TestDB:
    def test_versioning(self, client):
        delete_templates(client)
        fid = "burp_test_for_db_duplicates1"

        input_fids = {fid}

        with client.application.app_context():
            assert DbTemplate.get_template(fid, 'og') is None

            input_partial_fids = FindingHelper.full_fids_to_partial_fids(input_fids)
            FindingHelper.run_evaluation(client, "check_version_is_single", input_partial_fids, input_fids)

            version_history = DbTemplate.get_history(fid=fid, locale='og')
            assert len(version_history) == 1, "We've imported a new finding, it should only create one version in DB."
